==> react-ui-library-0.6.4.tgz: package/src/components/SubNavigationBar.js <==
import React, { PropTypes } from 'react'
import styled from 'styled-components'
import Pane from './Pane'
import Text from './Text'
import Link from './Link'
import Box from './Box'
import theme from './theme'

const SubNavigationBarLink = styled((props) =>
  <Link secondary textStyle='body1' paddingBottom marginLeft={3} marginRight={3} {...props} />)`
    &:active,
    &:hover,
    &.active {
      box-shadow: 0 1px ${props => props.theme.rawColors.blue500};
    }
  `

SubNavigationBarLink.defaultProps = {
  theme
}

const SubNavigationBarTitle = (props) =>
  <Text is='h2' textStyle='display4' {...props} />

SubNavigationBarTitle.defaultProps = {
  theme
}

const SubNavigationBarPane = (props) =>
  <Pane display='flex' white borderBottom {...props} />

SubNavigationBarPane.defaultProps = {
  theme
}

const SubNavigationBar = ({ left, right, children }) => {

  let leftChild
  if (typeof left === 'string') {
    leftChild = <SubNavigationBarTitle>{left}</SubNavigationBarTitle>
  } else {
    leftChild = left
  }

  return (
    <SubNavigationBarPane>
      <Pane width={3} padding flex='0 0 auto'>{leftChild}</Pane>
      <Pane flexAuto textAlign='center' display='flex' alignItems='flex-end' justifyContent='center'>{children}</Pane>
      <Pane width={3} textAlign='right' flex='0 0 auto'>{right}</Pane>
    </SubNavigationBarPane>
  )
}

SubNavigationBar.propTypes = {
  ...Box.propTypes,
  left: PropTypes.oneOfType([
    PropTypes.node,
    PropTypes.string
  ]),
  right: PropTypes.node
}

SubNavigationBar.defaultProps = {
  theme
}

export {
  SubNavigationBar,
  SubNavigationBarTitle,
  SubNavigationBarLink
}

==> react-ui-library-0.7.10.tgz: package/src/components/SubNavigationBar.js <==
import React, { PropTypes } from 'react'
import { css } from 'glamor'
import Pane from './Pane'
import Text from './Text'
import Link from './Link'
import Box from './Box'
import theme from './theme'

const SubNavigationBarLink = props => <Link {...css({
  '&:active, &:hover, &.active': {
    boxShadow: `0 1px ${theme.rawColors.blue500}`
  }
})} {...props} />

SubNavigationBarLink.defaultProps = {
  secondary: true,
  textStyle: 'body1',
  paddingBottom: true,
  marginX: 3
}

const SubNavigationBarTitle = props => <Text {...props} />

SubNavigationBarTitle.defaultProps = {
  is: 'h2',
  textStyle: 'display4'
}

const SubNavigationBarPane = props => <Pane {...props} />

SubNavigationBarPane.defaultProps = {
  display: 'flex',
  white: true,
  borderBottom: true
}

const SubNavigationBar = ({ left, right, children }) => {
  let leftChild
  if (typeof left === 'string') {
    leftChild = <SubNavigationBarTitle>{left}</SubNavigationBarTitle>
  } else {
    leftChild = left
  }

  return (
    <SubNavigationBarPane>
      <Pane width={3} padding flex='0 0 auto'>{leftChild}</Pane>
      <Pane flexAuto textAlign='center' display='flex' alignItems='flex-end' justifyContent='center'>{children}</Pane>
      <Pane width={3} textAlign='right' flex='0 0 auto'>{right}</Pane>
    </SubNavigationBarPane>
  )
}

SubNavigationBar.propTypes = {
  ...Box.propTypes,
  left: PropTypes.oneOfType([
    PropTypes.node,
    PropTypes.string
  ]),
  right: PropTypes.node
}

SubNavigationBar.defaultProps = {
  theme
}

export {
  SubNavigationBar,
  SubNavigationBarTitle,
  SubNavigationBarLink
}
